EscPosCommands class

Constructors

EscPosCommands()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

align(int alignment) → List<int>
barcode(String data, int type, int height, int width, int position, int font) → List<int>
beep() → List<int>
bold(bool on) → List<int>
carriageReturn() → List<int>
combine(List<List<int>> commandsList) → List<int>
cut() → List<int>
drawer(int pin, int onTime, int offTime) → List<int>
feed(int lines) → List<int>
fontSize(int width, int height) → List<int>
formFeed() → List<int>
image(Uint8List imageData, int width, int mode) → List<int>
initialize() → List<int>
lineFeed() → List<int>
partialCut() → List<int>
qrCode(String data, int size, int errorCorrection) → List<int>
text(String text) → List<int>
underline(int weight) → List<int>