libusb_container_id_descriptor class final

\ingroup libusb_desc A structure representing the Container ID descriptor. This descriptor is documented in section 9.6.2.3 of the USB 3.0 specification. All multiple-byte fields, except UUIDs, are represented in host-endian format.

Inheritance
Implemented types
Available extensions

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
bDescriptorType ↔ int
Descriptor type. Will have value \ref libusb_descriptor_type::LIBUSB_DT_DEVICE_CAPABILITY LIBUSB_DT_DEVICE_CAPABILITY in this context.
getter/setter pair
bDevCapabilityType ↔ int
Capability type. Will have value \ref libusb_capability_type::LIBUSB_BT_CONTAINER_ID LIBUSB_BT_CONTAINER_ID in this context.
getter/setter pair
bLength ↔ int
Size of this descriptor (in bytes)
getter/setter pair
bReserved ↔ int
Reserved field
getter/setter pair
ContainerID ↔ Array<Uint8>
128 bit UUID
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited