libusb_interface_association_descriptor class final

\ingroup libusb_desc A structure representing the standard USB interface association descriptor. This descriptor is documented in section 9.6.4 of the USB 3.0 specification. All multiple-byte fields are represented in host-endian format.

Inheritance
Implemented types
Available extensions

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
bDescriptorType ↔ int
Descriptor type. Will have value \ref libusb_descriptor_type::LIBUSB_DT_INTERFACE_ASSOCIATION LIBUSB_DT_INTERFACE_ASSOCIATION in this context.
getter/setter pair
bFirstInterface ↔ int
Interface number of the first interface that is associated with this function
getter/setter pair
bFunctionClass ↔ int
USB-IF class code for this function. A value of zero is not allowed in this descriptor. If this field is 0xff, the function class is vendor-specific. All other values are reserved for assignment by the USB-IF.
getter/setter pair
bFunctionProtocol ↔ int
USB-IF protocol code for this function. These codes are qualified by the values of the bFunctionClass and bFunctionSubClass fields.
getter/setter pair
bFunctionSubClass ↔ int
USB-IF subclass code for this function. If this field is not set to 0xff, all values are reserved for assignment by the USB-IF
getter/setter pair
bInterfaceCount ↔ int
Number of contiguous interfaces that are associated with this function
getter/setter pair
bLength ↔ int
Size of this descriptor (in bytes)
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iFunction ↔ int
Index of string descriptor describing this function
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited