libusb_interface_association_descriptor_array class final

\ingroup libusb_desc Structure containing an array of 0 or more interface association descriptors

Inheritance
  • Object
  • Struct
  • libusb_interface_association_descriptor_array
Implemented types
Available extensions

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode → int
The hash code for this object.
no setterinherited
iad ↔ Pointer<libusb_interface_association_descriptor>
Array of interface association descriptors. The size of this array is determined by the length field.
getter/setter pair
length ↔ int
Number of interface association descriptors contained. Read-only.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited