libusb_request_recipient enum

\ingroup libusb_misc Recipient bits of the \ref libusb_control_setup::bmRequestType "bmRequestType" field in control transfers. Values 4 through 31 are reserved.

Inheritance
Available extensions

Values

LIBUSB_RECIPIENT_DEVICE → const libusb_request_recipient

Device

const libusb_request_recipient(0)
LIBUSB_RECIPIENT_INTERFACE → const libusb_request_recipient

Interface

const libusb_request_recipient(1)
LIBUSB_RECIPIENT_ENDPOINT → const libusb_request_recipient

Endpoint

const libusb_request_recipient(2)
LIBUSB_RECIPIENT_OTHER → const libusb_request_recipient

Other

const libusb_request_recipient(3)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromValue(int value) → libusb_request_recipient

Constants

values → const List<libusb_request_recipient>
A constant List of the values in this enum, in order of their declaration.