libusb_version class final

\ingroup libusb_lib Structure providing the version of the libusb runtime

Inheritance
Implemented types
Available extensions

Constructors

libusb_version()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
describe ↔ Pointer<Char>
For ABI compatibility only.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
major ↔ int
Library major version.
getter/setter pair
micro ↔ int
Library micro version.
getter/setter pair
minor ↔ int
Library minor version.
getter/setter pair
nano ↔ int
Library nano version.
getter/setter pair
rc ↔ Pointer<Char>
Library release candidate suffix string, e.g. "-rc4".
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited