UsbDeviceInfo class

Constructors

UsbDeviceInfo({required int busNumber, required int deviceAddress, required int vendorId, required int productId, required int deviceClass, required int deviceSubClass, required int deviceProtocol, String? manufacturer, String? product, String? serialNumber})

Properties

busNumber → int
final
deviceAddress → int
final
deviceClass → int
final
deviceProtocol → int
final
deviceSubClass → int
final
hashCode → int
The hash code for this object.
no setterinherited
manufacturer → String?
final
product → String?
final
productId → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialNumber → String?
final
vendorId → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited